@@ -3,7 +3,10 @@
 sub new {
   my $class = shift;
 
-  $self = { scanner => Scanner->new, printer => Printer->new, };
+  $self = { scanner => Scanner->new,
+	    printer => Printer->new,
+	    compiler => Compiler->new,
+	    messagesystem => AIMessageSystem->new(Printer->new, Compiler->new), };
 
   bless $self, $class;
 }
@@ -25,6 +28,8 @@ sub scan {
   my $self = shift;
 
   $self->{scanner}->scan;
+
+  ### FIXME dispatch read scan to aimessagesystem
 }
 
 1;
